package com.mosty.sjzx.mapper;

import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.ApiOperation;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

@Mapper
public interface SgfxMapper {

    @ApiOperation("日统计-街面警情")
    List<Map<String, Object>> jmjq(Map<String, Object> map);

    @ApiOperation("日统计-违法犯罪警情")
    List<Map<String, Object>> wffzjq(Map<String, Object> map);

    @ApiOperation("日统计-总情警")
    List<Map<String, Object>> zjq(Map<String, Object> map);

    @ApiOperation("月统计-街面警情")
    List<Map<String, Object>> yjmjq(Map<String, Object> map);

    @ApiOperation("月统计-违法犯罪警情")
    List<Map<String, Object>> yzwffzjq(Map<String, Object> map);

    @ApiOperation("月统计-总警情")
    List<Map<String, Object>> yzjq(Map<String, Object> map);

    @ApiOperation("周统计-街面警情")
    List<Map<String, Object>> zjmjq(Map<String, Object> map);

    @ApiOperation("周统计-违法犯罪警情")
    List<Map<String, Object>> zwffzjq(Map<String, Object> map);

    @ApiOperation("周统计-总警情")
    List<Map<String, Object>> zzjq(Map<String, Object> map);

    @ApiOperation("日统计-街面警情")
    List<Map<String, Object>> gfsdfxJmjq(Map<String, Object> map);

    @ApiOperation("日统计-违法犯罪警情")
    List<Map<String, Object>> gfsdfxWffzjq(Map<String, Object> map);

    @ApiOperation("日统计-总警情")
    List<Map<String, Object>> gfsdfxZjq(Map<String, Object> map);

    @ApiOperation("月统计-街面警情")
    List<Map<String, Object>> gfsdfxYjmjq(Map<String, Object> map);

    @ApiOperation("月统计-违法犯罪警情")
    List<Map<String, Object>> ywffzjq(Map<String, Object> map);

    @ApiOperation("月统计-总警情")
    List<Map<String, Object>> gfsdfxYzjq(Map<String, Object> map);

    @ApiOperation("周统计-街面警情")
    List<Map<String, Object>> gfsdfxZjmjq(Map<String, Object> map);

    @ApiOperation("周统计-违法犯罪警情")
    List<Map<String, Object>> gfsdfxZwffzjq(Map<String, Object> map);

    @ApiOperation("周统计-总警情")
    List<Map<String, Object>> gfsdfxZzjq(Map<String, Object> map);

    @ApiOperation("案由类型")
    List<Map<String, Object>> aylx(@Param("code") String code);

    @ApiOperation("组织机构")
    List<Map<String, Object>> zzjg();

    @ApiOperation("警情统计")
    List<Map<String, Object>> zdgzJqtj(Map<String, Object> map);

    @ApiOperation("日统计")
    List<Map<String, Object>> rtj(Map<String, Object> map);

    @ApiOperation("月统计")
    List<Map<String, Object>> ytj(Map<String, Object> map);

    @ApiOperation("月统计")
    List<Map<String, Object>> ztj(Map<String, Object> map);

    @ApiOperation("日统计-三车人员预警")
    List<Map<String, Object>> scryyj(Map<String, Object> map);

    @ApiOperation("月统计-三车人员预警")
    List<Map<String, Object>> yscryyj(Map<String, Object> map);

    @ApiOperation("周统计-三车人员预警")
    List<Map<String, Object>> zscryyj(Map<String, Object> map);

    @ApiOperation("派出所发案分析--日统计")
    List<Map<String, Object>> pcsfafxRtj(Map<String, Object> map);

    @ApiOperation("派出所发案分析--月统计")
    List<Map<String, Object>> pcsfafxytj(Map<String, Object> map);

    @ApiOperation("派出所发案分析--周统计")
    List<Map<String, Object>> pcsfafxztj(Map<String, Object> map);

    @ApiOperation("专题分析-数据统计")
    List<Map<String, Object>> ztsjtj(Map<String, Object> map);

    @ApiOperation("专题分析-月数据统计")
    List<Map<String, Object>> yztsjtj(Map<String, Object> map);

    @ApiOperation("今日警情处置分析")
    List<Map<String, Object>> jrjqczfx(Map<String, Object> map);

    @ApiOperation("今日警情数量走势")
    List<Map<String, Object>> jrjqslzs(Map<String, Object> map);

    @ApiOperation("今日警情预警")
    List<Map<String, Object>> jrjqyj(Map<String, Object> map);

    @ApiOperation("警情类型统计")
    List<Map<String, Object>> jqlxtj(Map<String, Object> map);

    @ApiOperation("警情数量")
    int jqlbCount(Map<String, Object> map);

    @ApiOperation("警情列表")
    List<Map<String, Object>> jqlb(Map<String, Object> map);

    @ApiOperation("设备类型统计")
    List<Map<String, Object>> sblxtj(Map<String, Object> map);

    @ApiOperation("设备列表统计")
    int sblbCount(Map<String, Object> map);

    @ApiOperation("设备列表")
    List<Map<String, Object>> sblb(Map<String, Object> map);

    @ApiOperation("部门列表统计")
    List<Map<String, Object>> jwzbmlbtj(Map<String, Object> map);

    @ApiOperation("根据部门统计警务站")
    List<Map<String, Object>> bmtjjwz(Map<String, Object> map);

    @ApiOperation("车辆部门统计")
    List<Map<String, Object>> clbmtj(Map<String, Object> map);

    @ApiOperation("辅警部门统计")
    List<Map<String, Object>> fjbmtj(Map<String, Object> map);

    @ApiOperation("民警部门统计")
    List<Map<String, Object>> mjbmtj(Map<String, Object> map);

    @ApiOperation("柱状图统计")
    List<Map<String, Object>> zttjz(Map<String, Object> map);

    @ApiOperation("移动装备--部门列表统计")
    List<Map<String, Object>> lbtj(Map<String, Object> map);

    @ApiOperation("移动装备--根据部门统计")
    List<Map<String, Object>> bmtj(Map<String, Object> map);

    @ApiOperation("感知源-部门列表统计")
    List<Map<String, Object>> gzybmlbtj(Map<String, Object> map);
}
